%define mpiimpl openmpi
%define mpidir %_libexecdir/%mpiimpl

%define scalar_type complex
%if "%scalar_type" == "real"
%define alttype complex
%else
%define alttype real
%endif

%define oname petsc4py
%define ldir %_libexecdir/petsc-%scalar_type
Name: %oname-%scalar_type
Version: 1.0.2
%define exampledir %_docdir/%oname-%version/examples
Release: alt6.M51.1
Summary: PETSc for Python (%scalar_type scalars)
License: Public
Group: Sciences/Mathematics
Url: http://code.google.com/p/petsc4py
Packager: Eugeny A. Rostovtsev (REAL) <real at altlinux.org>

Source: http://petsc4py.googlecode.com/files/petsc4py-1.0.2.tar.gz

Requires: python-module-%name = %version-%release

BuildPreReq: python-devel
BuildPreReq: %mpiimpl-devel libpetsc-%scalar_type-devel python-module-numpy
BuildPreReq: libmpe2-devel libhdf5-mpi-devel libtriangle-devel libX11-devel
BuildPreReq: liby12m-devel libsundials-devel libsz2-devel zlib-devel
BuildPreReq: libexpat-devel libtetgen-devel python-module-mpi4py
%if "%scalar_type" == "complex"
BuildPreReq: libfftw3-mpi-devel libatlas-devel liblapack-devel
%endif

%description
Python bindings for PETSc (%scalar_type scalars).

%package -n python-module-%name
Summary: Python module with bindings for PETSc (%scalar_type scalars)
Group: Development/Python
%add_python_lib_path %ldir/python
%setup_python_module %oname
Provides: python%__python_version(%oname) = %version-%release
%py_provides %oname
Requires: %name = %version-%release

%description -n python-module-%name
Python module with bindings for PETSc (%scalar_type scalars)

Note: for work with this module You need run:
source %_bindir/%name.sh

%package -n %oname-doc
Summary: Documentation for Python bindings for PETSc
Group: Development/Documentation
BuildArch: noarch
Provides: %name-doc = %version-%release
Conflicts: %name-doc < %version-%release
Obsoletes: %name-doc < %version-%release

%description -n %oname-doc
Documentation for Python bindings for PETSc.

%package -n %oname-examples
Summary: Examples for Python bindings for PETSc
Group: Development/Documentation
BuildArch: noarch
Provides: %name-examples = %version-%release
Conflicts: %name-examples < %version-%release
Obsoletes: %name-examples < %version-%release
%py_requires matplotlib

%description -n %oname-examples
Examples for Python bindings for PETSc.

%prep
%setup

%install
mpi-selector --set %mpiimpl
source %_bindir/petsc-%scalar_type.sh
for i in $(ls %mpidir/lib/%mpiimpl/*.so); do
	MPILIBS="$MPILIBS '$i', "
done
sed -i 's|@MPIDIR@|%mpidir|g' conf/core/confutils.py
sed -i 's|@MPIIMPL@|%mpiimpl|g' conf/core/confutils.py
sed -i "s|@PETSCDIR@|$PETSC_DIR|g" conf/core/confutils.py
sed -i "s|@MPILIBS@|$MPILIBS|g" conf/core/confcore.py
%python_build

%python_install --optimize=2

install -d %buildroot%ldir/python
mv %buildroot%python_sitelibdir/* \
	%buildroot%ldir/python/
sed -i 's|^\(PETSC_ARCH\).*|\1 =|' \
	%buildroot%ldir/python/%oname/lib/petsc.cfg
pushd %buildroot%ldir/python/%oname/lib/linux-gnu
for i in $(ls); do
	ln -s linux-gnu/$i ../
done
popd

install -d %buildroot%exampledir
cp -fR docs/*.pdf docs/html %buildroot%exampledir/
sed -i 's|@EXAMPLES@|%exampledir|g' demo/kspsolve/test_mat_*.py
cp -fR demo/* %buildroot%exampledir/

# example modules

pushd demo/bratu2d
%make_build
install -m644 *.so %buildroot%ldir/python
popd
pushd demo/poisson3d
f2py -m del2lib -c del2lib.f90
install -m644 *.so %buildroot%ldir/python
popd

%files
%doc HISTORY.txt LICENSE.txt PKG-INFO README.txt

%files -n python-module-%name
%dir %ldir/python
%ldir/python/*

%if "%scalar_type" == "real"
%files -n %oname-doc
%doc %dir %_docdir/%oname-%version
%doc %_docdir/%oname-%version/*
%exclude %_docdir/%oname-%version/examples

%files -n %oname-examples
%doc %dir %_docdir/%oname-%version
%doc %_docdir/%oname-%version/examples
%endif

%changelog
* Wed Dec 16 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt6.M51.1
- Port for branch 5.1

* Tue Sep 08 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt6
- Rebuilt with PETSc-3.0.0_p7-alt6
- Fixed examples and added example modules

* Tue Aug 18 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt5
- Rebuilt with PETSc-3.0.0_p7-alt5

* Tue Jul 28 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt4.1
- Renamed petsc4py-real-doc -> petsc4py-doc
  and petsc4py-real-examples -> petsc4py-examples

* Sun Jul 19 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt3
- Moved module files from %python_sitelibdir into %ldir/python

* Sat Jul 18 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt2
- Added link to Python module into PETSC_DIR/python

* Tue Jul 14 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.2-alt1
- Initial build for Sisyphus
